// Copyright 2021 The Prometheus Authors
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
import { snippet } from '@codemirror/autocomplete';
export const durationTerms = [{ label: 'y' }, { label: 'w' }, { label: 'd' }, { label: 'h' }, { label: 'm' }, { label: 's' }, { label: 'ms' }];
export const matchOpTerms = [{ label: '=' }, { label: '!=' }, { label: '=~' }, { label: '!~' }];
export const binOpTerms = [
    { label: '^' },
    { label: '*' },
    { label: '/' },
    { label: '%' },
    { label: '+' },
    { label: '-' },
    { label: '==' },
    { label: '>=' },
    { label: '>' },
    { label: '<' },
    { label: '<=' },
    { label: '!=' },
    { label: 'atan2' },
    { label: 'and' },
    { label: 'or' },
    { label: 'unless' },
];
export const binOpModifierTerms = [
    { label: 'on', info: 'Match only on specified labels', type: 'keyword' },
    { label: 'ignoring', info: 'Ignore specified labels for matching', type: 'keyword' },
    { label: 'group_left', info: 'Allow many-to-one matching', type: 'keyword' },
    { label: 'group_right', info: 'Allow one-to-many matching', type: 'keyword' },
];
export const atModifierTerms = [
    { label: 'start()', info: 'resolve to the start of the query', type: 'keyword' },
    { label: 'end()', info: 'resolve to the end of the query', type: 'keyword' },
];
export const functionIdentifierTerms = [
    {
        label: 'abs',
        detail: 'function',
        info: 'Return absolute values of input series',
        type: 'function',
    },
    {
        label: 'absent',
        detail: 'function',
        info: 'Determine whether input vector is empty',
        type: 'function',
    },
    {
        label: 'absent_over_time',
        detail: 'function',
        info: 'Determine whether input range vector is empty',
        type: 'function',
    },
    {
        label: 'acos',
        detail: 'function',
        info: 'Calculate the arccosine, in radians, for input series',
        type: 'function',
    },
    {
        label: 'acosh',
        detail: 'function',
        info: 'Calculate the inverse hyperbolic cosine, in radians, for input series',
        type: 'function',
    },
    {
        label: 'asin',
        detail: 'function',
        info: 'Calculate the arcsine, in radians, for input series',
        type: 'function',
    },
    {
        label: 'asinh',
        detail: 'function',
        info: 'Calculate the inverse hyperbolic sine, in radians, for input series',
        type: 'function',
    },
    {
        label: 'atan',
        detail: 'function',
        info: 'Calculate the arctangent, in radians, for input series',
        type: 'function',
    },
    {
        label: 'atanh',
        detail: 'function',
        info: 'Calculate the inverse hyperbolic tangent, in radians, for input series',
        type: 'function',
    },
    {
        label: 'avg_over_time',
        detail: 'function',
        info: 'Average series values over time',
        type: 'function',
    },
    {
        label: 'ceil',
        detail: 'function',
        info: 'Round up values of input series to nearest integer',
        type: 'function',
    },
    {
        label: 'changes',
        detail: 'function',
        info: 'Return number of value changes in input series over time',
        type: 'function',
    },
    {
        label: 'clamp',
        detail: 'function',
        info: 'Limit the value of input series between a minimum and a maximum',
        type: 'function',
    },
    {
        label: 'clamp_max',
        detail: 'function',
        info: 'Limit the value of input series to a maximum',
        type: 'function',
    },
    {
        label: 'clamp_min',
        detail: 'function',
        info: 'Limit the value of input series to a minimum',
        type: 'function',
    },
    {
        label: 'cos',
        detail: 'function',
        info: 'Calculate the cosine, in radians, for input series',
        type: 'function',
        // Avoid ranking higher than `count`.
        boost: -1,
    },
    {
        label: 'cosh',
        detail: 'function',
        info: 'Calculate the hyperbolic cosine, in radians, for input series',
        type: 'function',
        // Avoid ranking higher than `count`.
        boost: -1,
    },
    {
        label: 'count_over_time',
        detail: 'function',
        info: 'Count the number of values for each input series',
        type: 'function',
    },
    {
        label: 'days_in_month',
        detail: 'function',
        info: 'Return the number of days in current month for provided timestamps',
        type: 'function',
    },
    {
        label: 'day_of_month',
        detail: 'function',
        info: 'Return the day of the month for provided timestamps',
        type: 'function',
    },
    {
        label: 'day_of_week',
        detail: 'function',
        info: 'Return the day of the week for provided timestamps',
        type: 'function',
    },
    {
        label: 'day_of_year',
        detail: 'function',
        info: 'Return the day of the year for provided timestamps',
        type: 'function',
    },
    {
        label: 'deg',
        detail: 'function',
        info: 'Convert radians to degrees for input series',
        type: 'function',
        // Avoid ranking higher than `delta`.
        boost: -1,
    },
    {
        label: 'delta',
        detail: 'function',
        info: 'Calculate the difference between beginning and end of a range vector (for gauges)',
        type: 'function',
    },
    {
        label: 'deriv',
        detail: 'function',
        info: 'Calculate the per-second derivative over series in a range vector (for gauges)',
        type: 'function',
    },
    {
        label: 'exp',
        detail: 'function',
        info: 'Calculate exponential function for input vector values',
        type: 'function',
    },
    {
        label: 'floor',
        detail: 'function',
        info: 'Round down values of input series to nearest integer',
        type: 'function',
    },
    {
        label: 'histogram_count',
        detail: 'function',
        info: 'Return the count of observations from a native histogram (experimental feature)',
        type: 'function',
    },
    {
        label: 'histogram_fraction',
        detail: 'function',
        info: 'Calculate fractions of observations within an interval from a native histogram (experimental feature)',
        type: 'function',
    },
    {
        label: 'histogram_quantile',
        detail: 'function',
        info: 'Calculate quantiles from native histograms (experimental) and from conventional histogram buckets',
        type: 'function',
    },
    {
        label: 'histogram_sum',
        detail: 'function',
        info: 'Return the sum of observations from a native histogram (experimental feature)',
        type: 'function',
    },
    {
        label: 'histogram_stddev',
        detail: 'function',
        info: 'Estimate the standard deviation of observations from a native histogram (experimental feature)',
        type: 'function',
    },
    {
        label: 'histogram_stdvar',
        detail: 'function',
        info: 'Estimate the standard variance of observations from a native histogram (experimental feature)',
        type: 'function',
    },
    {
        label: 'holt_winters',
        detail: 'function',
        info: 'Calculate smoothed value of input series',
        type: 'function',
    },
    {
        label: 'hour',
        detail: 'function',
        info: 'Return the hour of the day for provided timestamps',
        type: 'function',
    },
    {
        label: 'idelta',
        detail: 'function',
        info: 'Calculate the difference between the last two samples of a range vector (for counters)',
        type: 'function',
    },
    {
        label: 'increase',
        detail: 'function',
        info: 'Calculate the increase in value over a range of time (for counters)',
        type: 'function',
    },
    {
        label: 'irate',
        detail: 'function',
        info: 'Calculate the per-second increase over the last two samples of a range vector (for counters)',
        type: 'function',
    },
    {
        label: 'label_replace',
        detail: 'function',
        info: 'Set or replace label values',
        type: 'function',
    },
    {
        label: 'label_join',
        detail: 'function',
        info: 'Join together label values into new label',
        type: 'function',
    },
    {
        label: 'last_over_time',
        detail: 'function',
        info: 'The most recent point value in specified interval.',
        type: 'function',
    },
    {
        label: 'ln',
        detail: 'function',
        info: 'Calculate natural logarithm of input series',
        type: 'function',
    },
    {
        label: 'log10',
        detail: 'function',
        info: 'Calulcate base-10 logarithm of input series',
        type: 'function',
    },
    {
        label: 'log2',
        detail: 'function',
        info: 'Calculate base-2 logarithm of input series',
        type: 'function',
    },
    {
        label: 'max_over_time',
        detail: 'function',
        info: 'Return the maximum value over time for input series',
        type: 'function',
    },
    {
        label: 'min_over_time',
        detail: 'function',
        info: 'Return the minimum value over time for input series',
        type: 'function',
    },
    {
        label: 'minute',
        detail: 'function',
        info: 'Return the minute of the hour for provided timestamps',
        type: 'function',
    },
    {
        label: 'month',
        detail: 'function',
        info: 'Return the month for provided timestamps',
        type: 'function',
    },
    {
        label: 'pi',
        detail: 'function',
        info: 'Return pi',
        type: 'function',
    },
    {
        label: 'predict_linear',
        detail: 'function',
        info: 'Predict the value of a gauge into the future',
        type: 'function',
    },
    {
        label: 'present_over_time',
        detail: 'function',
        info: 'the value 1 for any series in the specified interval',
        type: 'function',
    },
    {
        label: 'quantile_over_time',
        detail: 'function',
        info: 'Calculate value quantiles over time for input series',
        type: 'function',
    },
    {
        label: 'rad',
        detail: 'function',
        info: 'Convert degrees to radians for input series',
        type: 'function',
        // Avoid ranking higher than `rate`.
        boost: -1,
    },
    {
        label: 'rate',
        detail: 'function',
        info: 'Calculate per-second increase over a range vector (for counters)',
        type: 'function',
    },
    {
        label: 'resets',
        detail: 'function',
        info: 'Return number of value decreases (resets) in input series of time',
        type: 'function',
    },
    {
        label: 'round',
        detail: 'function',
        info: 'Round values of input series to nearest integer',
        type: 'function',
    },
    {
        label: 'scalar',
        detail: 'function',
        info: 'Convert single-element series vector into scalar value',
        type: 'function',
    },
    {
        label: 'sgn',
        detail: 'function',
        info: 'Returns the sign of the instant vector',
        type: 'function',
    },
    {
        label: 'sin',
        detail: 'function',
        info: 'Calculate the sine, in radians, for input series',
        type: 'function',
    },
    {
        label: 'sinh',
        detail: 'function',
        info: 'Calculate the hyperbolic sine, in radians, for input series',
        type: 'function',
    },
    {
        label: 'sort',
        detail: 'function',
        info: 'Sort input series ascendingly by value',
        type: 'function',
    },
    {
        label: 'sort_desc',
        detail: 'function',
        info: 'Sort input series descendingly by value',
        type: 'function',
    },
    {
        label: 'sqrt',
        detail: 'function',
        info: 'Return the square root for input series',
        type: 'function',
    },
    {
        label: 'stddev_over_time',
        detail: 'function',
        info: 'Calculate the standard deviation within input series over time',
        type: 'function',
    },
    {
        label: 'stdvar_over_time',
        detail: 'function',
        info: 'Calculate the standard variance within input series over time',
        type: 'function',
    },
    {
        label: 'sum_over_time',
        detail: 'function',
        info: 'Calculate the sum over the values of input series over time',
        type: 'function',
    },
    {
        label: 'tan',
        detail: 'function',
        info: 'Calculate the tangent, in radians, for input series',
        type: 'function',
    },
    {
        label: 'tanh',
        detail: 'function',
        info: 'Calculate the hyperbolic tangent, in radians, for input series',
        type: 'function',
    },
    {
        label: 'time',
        detail: 'function',
        info: 'Return the Unix timestamp at the current evaluation time',
        type: 'function',
    },
    {
        label: 'timestamp',
        detail: 'function',
        info: 'Return the Unix timestamp for the samples in the input vector',
        type: 'function',
    },
    {
        label: 'vector',
        detail: 'function',
        info: 'Convert a scalar value into a single-element series vector',
        type: 'function',
    },
    {
        label: 'year',
        detail: 'function',
        info: 'Return the year for provided timestamps',
        type: 'function',
    },
    // metricsql
    {
        label: 'aggr_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#aggr_over_time',
        type: 'function',
    },
    {
        label: 'alias',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#alias',
        type: 'function',
    },
    {
        label: 'ascent_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#ascent_over_time',
        type: 'function',
    },
    {
        label: 'bitmap_and',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#bitmap_and',
        type: 'function',
    },
    {
        label: 'bitmap_or',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#bitmap_or',
        type: 'function',
    },
    {
        label: 'bitmap_xor',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#bitmap_xor',
        type: 'function',
    },
    {
        label: 'buckets_limit',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#buckets_limit',
        type: 'function',
    },
    {
        label: 'changes_prometheus',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#changes_prometheus',
        type: 'function',
    },
    {
        label: 'count_eq_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#count_eq_over_time',
        type: 'function',
    },
    {
        label: 'count_gt_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#count_gt_over_time',
        type: 'function',
    },
    {
        label: 'count_le_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#count_le_over_time',
        type: 'function',
    },
    {
        label: 'count_ne_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#count_ne_over_time',
        type: 'function',
    },
    {
        label: 'decreases_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#decreases_over_time',
        type: 'function',
    },
    {
        label: 'default_rollup',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#default_rollup',
        type: 'function',
    },
    {
        label: 'delta_prometheus',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#delta_prometheus',
        type: 'function',
    },
    {
        label: 'deriv_fast',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#deriv_fast',
        type: 'function',
    },
    {
        label: 'descent_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#descent_over_time',
        type: 'function',
    },
    {
        label: 'distinct_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#distinct_over_time',
        type: 'function',
    },
    {
        label: 'drop_common_labels',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#drop_common_labels',
        type: 'function',
    },
    {
        label: 'duration_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#duration_over_time',
        type: 'function',
    },
    {
        label: 'first_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#first_over_time',
        type: 'function',
    },
    {
        label: 'geomean_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#geomean_over_time',
        type: 'function',
    },
    {
        label: 'histogram_avg',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#histogram_avg',
        type: 'function',
    },
    {
        label: 'histogram_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#histogram_over_time',
        type: 'function',
    },
    {
        label: 'histogram_quantiles',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#histogram_quantiles',
        type: 'function',
    },
    {
        label: 'histogram_share',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#histogram_share',
        type: 'function',
    },
    {
        label: 'histogram_stddev',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#histogram_stddev',
        type: 'function',
    },
    {
        label: 'histogram_stdvar',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#histogram_stdvar',
        type: 'function',
    },
    {
        label: 'hoeffding_bound_lower',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#hoeffding_bound_lower',
        type: 'function',
    },
    {
        label: 'hoeffding_bound_upper',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#hoeffding_bound_upper',
        type: 'function',
    },
    {
        label: 'ideriv',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#ideriv',
        type: 'function',
    },
    {
        label: 'increase_prometheus',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#increase_prometheus',
        type: 'function',
    },
    {
        label: 'increase_pure',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#increase_pure',
        type: 'function',
    },
    {
        label: 'increases_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#increases_over_time',
        type: 'function',
    },
    {
        label: 'integrate',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#integrate',
        type: 'function',
    },
    {
        label: 'interpolate',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#interpolate',
        type: 'function',
    },
    {
        label: 'keep_last_value',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#keep_last_value',
        type: 'function',
    },
    {
        label: 'keep_next_value',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#keep_next_value',
        type: 'function',
    },
    {
        label: 'label_copy',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_copy',
        type: 'function',
    },
    {
        label: 'label_del',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_del',
        type: 'function',
    },
    {
        label: 'label_graphite_group',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_graphite_group',
        type: 'function',
    },
    {
        label: 'label_keep',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_keep',
        type: 'function',
    },
    {
        label: 'label_lowercase',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_lowercase',
        type: 'function',
    },
    {
        label: 'label_map',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_map',
        type: 'function',
    },
    {
        label: 'label_match',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_match',
        type: 'function',
    },
    {
        label: 'label_mismatch',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_mismatch',
        type: 'function',
    },
    {
        label: 'label_move',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_move',
        type: 'function',
    },
    {
        label: 'label_set',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_set',
        type: 'function',
    },
    {
        label: 'label_transform',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_transform',
        type: 'function',
    },
    {
        label: 'label_uppercase',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_uppercase',
        type: 'function',
    },
    {
        label: 'label_value',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#label_value',
        type: 'function',
    },
    {
        label: 'lag',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#lag',
        type: 'function',
    },
    {
        label: 'lifetime',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#lifetime',
        type: 'function',
    },
    {
        label: 'limit_offset',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#limit_offset',
        type: 'function',
    },
    {
        label: 'mad_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#mad_over_time',
        type: 'function',
    },
    {
        label: 'median_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#median_over_time',
        type: 'function',
    },
    {
        label: 'mode_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#mode_over_time',
        type: 'function',
    },
    {
        label: 'now',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#now',
        type: 'function',
    },
    {
        label: 'prometheus_buckets',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#prometheus_buckets',
        type: 'function',
    },
    {
        label: 'quantiles_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#quantiles_over_time',
        type: 'function',
    },
    {
        label: 'rand',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rand',
        type: 'function',
    },
    {
        label: 'rand_exponential',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rand_exponential',
        type: 'function',
    },
    {
        label: 'rand_normal',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rand_normal',
        type: 'function',
    },
    {
        label: 'range_avg',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_avg',
        type: 'function',
    },
    {
        label: 'range_first',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_first',
        type: 'function',
    },
    {
        label: 'range_last',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_last',
        type: 'function',
    },
    {
        label: 'range_linear_regression',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_linear_regression',
        type: 'function',
    },
    {
        label: 'range_mad',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_mad',
        type: 'function',
    },
    {
        label: 'range_max',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_max',
        type: 'function',
    },
    {
        label: 'range_min',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_min',
        type: 'function',
    },
    {
        label: 'range_normalize',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_normalize',
        type: 'function',
    },
    {
        label: 'range_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_over_time',
        type: 'function',
    },
    {
        label: 'range_quantile',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_quantile',
        type: 'function',
    },
    {
        label: 'range_stddev',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_stddev',
        type: 'function',
    },
    {
        label: 'range_stdvar',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_stdvar',
        type: 'function',
    },
    {
        label: 'range_sum',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_sum',
        type: 'function',
    },
    {
        label: 'range_trim_outliers',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_trim_outliers',
        type: 'function',
    },
    {
        label: 'range_trim_spikes',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_trim_spikes',
        type: 'function',
    },
    {
        label: 'range_trim_zscore',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_trim_zscore',
        type: 'function',
    },
    {
        label: 'range_zscore',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#range_zscore',
        type: 'function',
    },
    {
        label: 'rate_over_sum',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rate_over_sum',
        type: 'function',
    },
    {
        label: 'remove_resets',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#remove_resets',
        type: 'function',
    },
    {
        label: 'rollup',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rollup',
        type: 'function',
    },
    {
        label: 'rollup_candlestick',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rollup_candlestick',
        type: 'function',
    },
    {
        label: 'rollup_delta',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rollup_delta',
        type: 'function',
    },
    {
        label: 'rollup_deriv',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rollup_deriv',
        type: 'function',
    },
    {
        label: 'rollup_increase',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rollup_increase',
        type: 'function',
    },
    {
        label: 'rollup_rate',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rollup_rate',
        type: 'function',
    },
    {
        label: 'rollup_scrape_interval',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#rollup_scrape_interval',
        type: 'function',
    },
    {
        label: 'running_avg',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#running_avg',
        type: 'function',
    },
    {
        label: 'running_max',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#running_max',
        type: 'function',
    },
    {
        label: 'running_min',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#running_min',
        type: 'function',
    },
    {
        label: 'running_sum',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#running_sum',
        type: 'function',
    },
    {
        label: 'scrape_interval',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#scrape_interval',
        type: 'function',
    },
    {
        label: 'share_eq_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#share_eq_over_time',
        type: 'function',
    },
    {
        label: 'share_gt_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#share_gt_over_time',
        type: 'function',
    },
    {
        label: 'share_le_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#share_le_over_time',
        type: 'function',
    },
    {
        label: 'smooth_exponential',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#smooth_exponential',
        type: 'function',
    },
    {
        label: 'sort_by_label',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#sort_by_label',
        type: 'function',
    },
    {
        label: 'sort_by_label_desc',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#sort_by_label_desc',
        type: 'function',
    },
    {
        label: 'sort_by_label_numeric',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#sort_by_label_numeric',
        type: 'function',
    },
    {
        label: 'sort_by_label_numeric_desc',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#sort_by_label_numeric_desc',
        type: 'function',
    },
    {
        label: 'stale_samples_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#stale_samples_over_time',
        type: 'function',
    },
    {
        label: 'step',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#step',
        type: 'function',
    },
    {
        label: 'sum2_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#sum2_over_time',
        type: 'function',
    },
    {
        label: 'tfirst_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#tfirst_over_time',
        type: 'function',
    },
    {
        label: 'timestamp_with_name',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#timestamp_with_name',
        type: 'function',
    },
    {
        label: 'timezone_offset',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#timezone_offset',
        type: 'function',
    },
    {
        label: 'tlast_change_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#tlast_change_over_time',
        type: 'function',
    },
    {
        label: 'tlast_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#tlast_over_time',
        type: 'function',
    },
    {
        label: 'tmax_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#tmax_over_time',
        type: 'function',
    },
    {
        label: 'tmin_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#tmin_over_time',
        type: 'function',
    },
    {
        label: 'union',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#union',
        type: 'function',
    },
    {
        label: 'zscore_over_time',
        detail: 'function',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#zscore_over_time',
        type: 'function',
    },
];
export const aggregateOpTerms = [
    {
        label: 'avg',
        detail: 'aggregation',
        info: 'Calculate the average over dimensions',
        type: 'keyword',
    },
    {
        label: 'bottomk',
        detail: 'aggregation',
        info: 'Smallest k elements by sample value',
        type: 'keyword',
    },
    {
        label: 'count',
        detail: 'aggregation',
        info: 'Count number of elements in the vector',
        type: 'keyword',
    },
    {
        label: 'count_values',
        detail: 'aggregation',
        info: 'Count number of elements with the same value',
        type: 'keyword',
    },
    {
        label: 'group',
        detail: 'aggregation',
        info: 'Group series, while setting the sample value to 1',
        type: 'keyword',
    },
    {
        label: 'max',
        detail: 'aggregation',
        info: 'Select maximum over dimensions',
        type: 'keyword',
    },
    {
        label: 'min',
        detail: 'aggregation',
        info: 'Select minimum over dimensions',
        type: 'keyword',
    },
    {
        label: 'quantile',
        detail: 'aggregation',
        info: 'Calculate φ-quantile (0 ≤ φ ≤ 1) over dimensions',
        type: 'keyword',
    },
    {
        label: 'stddev',
        detail: 'aggregation',
        info: 'Calculate population standard deviation over dimensions',
        type: 'keyword',
    },
    {
        label: 'stdvar',
        detail: 'aggregation',
        info: 'Calculate population standard variance over dimensions',
        type: 'keyword',
    },
    {
        label: 'sum',
        detail: 'aggregation',
        info: 'Calculate sum over dimensions',
        type: 'keyword',
    },
    {
        label: 'topk',
        detail: 'aggregation',
        info: 'Largest k elements by sample value',
        type: 'keyword',
    },
    // metricsql
    {
        label: 'any',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#any',
        type: 'keyword',
    },
    {
        label: 'bottomk_avg',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#bottomk_avg',
        type: 'keyword',
    },
    {
        label: 'bottomk_max',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#bottomk_max',
        type: 'keyword',
    },
    {
        label: 'bottomk_median',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#bottomk_median',
        type: 'keyword',
    },
    {
        label: 'bottomk_last',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#bottomk_last',
        type: 'keyword',
    },
    {
        label: 'bottomk_min',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#bottomk_min',
        type: 'keyword',
    },
    {
        label: 'distinct',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#distinct',
        type: 'keyword',
    },
    {
        label: 'geomean',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#geomean',
        type: 'keyword',
    },
    {
        label: 'histogram',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#histogram',
        type: 'keyword',
    },
    {
        label: 'limitk',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#limitk',
        type: 'keyword',
    },
    {
        label: 'mad',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#mad',
        type: 'keyword',
    },
    {
        label: 'median',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#median',
        type: 'keyword',
    },
    {
        label: 'mode',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#mode',
        type: 'keyword',
    },
    {
        label: 'outliers_mad',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#outliers_mad',
        type: 'keyword',
    },
    {
        label: 'outliersk',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#outliersk',
        type: 'keyword',
    },
    {
        label: 'quantiles',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#quantiles',
        type: 'keyword',
    },
    {
        label: 'share',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#share',
        type: 'keyword',
    },
    {
        label: 'sum2',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#sum2',
        type: 'keyword',
    },
    {
        label: 'topk_avg',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#topk_avg',
        type: 'keyword',
    },
    {
        label: 'topk_max',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#topk_max',
        type: 'keyword',
    },
    {
        label: 'topk_median',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#topk_median',
        type: 'keyword',
    },
    {
        label: 'topk_last',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#topk_last',
        type: 'keyword',
    },
    {
        label: 'topk_min',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#topk_min',
        type: 'keyword',
    },
    {
        label: 'zscore',
        detail: 'aggregation',
        info: 'https://docs.victoriametrics.com/MetricsQL.html#zscore',
        type: 'keyword',
    },
];
export const aggregateOpModifierTerms = [
    {
        label: 'by',
        info: 'Keep the listed labels, remove all others.',
        type: 'keyword',
    },
    {
        label: 'without',
        info: 'Remove the listed labels, preserve all others.',
        type: 'keyword',
    },
];
export const numberTerms = [
    { label: 'nan', info: 'Floating-point NaN value', type: 'constant' },
    { label: 'inf', info: 'Floating-point infinity', type: 'constant' },
];
export const snippets = [
    {
        label: 'sum(rate(__input_vector__[5m]))',
        type: 'function',
        detail: 'snippet',
        info: 'Sum over rates of increase',
        apply: snippet('sum(rate(${__input_vector__}[5m]))'),
    },
    {
        label: 'histogram_quantile(__quantile__, sum by(le) (rate(__histogram_metric__[5m])))',
        type: 'function',
        detail: 'snippet',
        info: 'Approximate a quantile value from an aggregated histogram',
        apply: snippet('histogram_quantile(${__quantile__}, sum by(le) (rate(${__histogram_metric__}[5m])))'),
    },
    {
        label: 'label_replace(__input_vector__, "__dst__", "__replacement__", "__src__", "__regex__")',
        type: 'function',
        detail: 'snippet',
        info: 'Set or replace a label value in an input vector',
        apply: snippet('label_replace(${__input_vector__}, "${__dst__}", "${__replacement__}", "${__src__}", "${__regex__}")'),
    },
    {
        label: 'topk(__rank_number__, __input_vector__)',
        type: 'function',
        detail: 'snippet',
        info: 'Largest k elements by sample value',
        apply: snippet('topk(${__rank_number__}, ${__input_vector__})'),
    },
    {
        label: 'bottomk(__rank_number__, __input_vector__)',
        type: 'function',
        detail: 'snippet',
        info: 'Smallest k elements by sample value',
        apply: snippet('bottomk(${__rank_number__}, ${__input_vector__})'),
    },
    {
        label: 'count_values("__label_name__", __input_vector__)',
        type: 'function',
        detail: 'snippet',
        info: 'Count the number of series per distinct sample value',
        apply: snippet('count_values("${__label_name__}", ${__metric__})'),
    },
];
//# sourceMappingURL=promql.terms.js.map